<p align="center">
  <img height="120" style="height: 120px" src="https://github.com/pwwang/immunopipe/blob/dev/docs/logo.png?raw=true">
</p>
<p align="center">Integrative analysis for single-cell RNA sequencing and single-cell TCR sequencing data</p>
<hr />

`immunopipe` is a pipeline based on [`pipen`](https://github.com/pwwang/pipen) framework. It includes a set of processes for scTCR- and scRNA-seq data analysis in `R`, `python` and `bash`. The pipeline is designed to be flexible and configurable.

![immunopipe](https://github.com/pwwang/immunopipe/blob/dev/docs/immunopipe.flowchart.png?raw=true)

## Documentaion

[https://pwwang.github.io/immunopipe](https://pwwang.github.io/immunopipe)

## Proposing more analyses

If you have any suggestions for more analyses, please feel free to open an issue [here](https://github.com/pwwang/immunopipe/issues/new)

## Example

[https://github.com/pwwang/immunopipe-example](https://github.com/pwwang/immunopipe-example)
